py-opensecrets changelog
==========================

0.3.1
    * Fix requirements

0.3.0
-----
    * Use python requests instead of httplib2 by @ndanielsen

0.2.4
-----
    * Compatibility fixes for python 3.4, 3.5 by @ndanielsen

0.2.3
-----
    * Fork and restructure package by @ndanielsen
    * Forked from https://github.com/robrem/opensecrets-crpapi

0.2.X
-----
    * Doc strings, tests and added Independent Expenditures by @robrem

0.1.X
-----
    * Core concept, code and magic sunbeams by James Turk @jamesturk
    * Based on python-sunlightapi, a project of Sunlight Labs (c) 2008.
    * Forked at some point by bpilkerton at https://github.com/bpilkerton/python-crpapi
